@@ -6,6 +6,7 @@ from .authhandler import (
     LDAPAuth,
     OAuth2,
     SAMLAuth,
+    SAMLAuth2,
     SMSAuth,
     TwitterAuth,
 )
@@ -18,6 +19,7 @@ __all__ = [
     'LDAPAuth',
     'OAuth2',
     'SAMLAuth',
+    'SAMLAuth2',
     'SMSAuth',
     'TwitterAuth',
 ]
